@@ -20,7 +20,9 @@ $tts=array();
 $tts["cepstral"]= array(
       "name" => "cepstral",
       "call"  => "/opt/swift/bin/swift",
-      "options" => array('-n $voice -m text','-f $filename', '-o $filename.$iformat'),
+      "options" => array('-n $voice -m ssml','-f $filename', '-o $filename.$iformat'),
+      #Force 8 bits need ?
+      #"options" => array('-n $voice -m text','-f $filename', '-p audio/sampling-rate=8000', '-o $filename.$iformat'),
       "voices"=>array(
                       'David'  => array(
                                           'type'=>'male',
